# ------------------------------------------------------------------
#
#  releasewebfonts.sh
#  Copyright 2015 Christopher Simpkins
#  MIT license
#
# ------------------------------------------------------------------

# DESCRIPTION
#  Moves web font builds to release directories


# EOT files Latin subset
cp webfont-Hack-Latin/hack-regular-latin-webfont.eot ../../build/webfonts/fonts/eot/latin/hack-regular-latin-webfont.eot
cp webfont-Hack-Latin/hack-italic-latin-webfont.eot ../../build/webfonts/fonts/eot/latin/hack-italic-latin-webfont.eot
cp webfont-Hack-Latin/hack-bold-latin-webfont.eot ../../build/webfonts/fonts/eot/latin/hack-bold-latin-webfont.eot
cp webfont-Hack-Latin/hack-bolditalic-latin-webfont.eot ../../build/webfonts/fonts/eot/latin/hack-bolditalic-latin-webfont.eot

# EOT files entire set
cp webfont-Hack/hack-regular-webfont.eot ../../build/webfonts/fonts/eot/hack-regular-webfont.eot
cp webfont-Hack/hack-italic-webfont.eot ../../build/webfonts/fonts/eot/hack-italic-webfont.eot
cp webfont-Hack/hack-bold-webfont.eot ../../build/webfonts/fonts/eot/hack-bold-webfont.eot
cp webfont-Hack/hack-bolditalic-webfont.eot ../../build/webfonts/fonts/eot/hack-bolditalic-webfont.eot

echo "EOT files copied to webfonts release directories"

# # SVG files Latin subset
# cp webfont-Hack-Latin/hack-regular-latin-webfont.svg ../../build/webfonts/fonts/svg/latin/hack-regular-latin-webfont.svg
# cp webfont-Hack-Latin/hack-italic-latin-webfont.svg ../../build/webfonts/fonts/svg/latin/hack-italic-latin-webfont.svg
# cp webfont-Hack-Latin/hack-bold-latin-webfont.svg ../../build/webfonts/fonts/svg/latin/hack-bold-latin-webfont.svg
# cp webfont-Hack-Latin/hack-bolditalic-latin-webfont.svg ../../build/webfonts/fonts/svg/latin/hack-bolditalic-latin-webfont.svg

# # SVG files entire set
# cp webfont-Hack/hack-regular-webfont.svg ../../build/webfonts/fonts/svg/hack-regular-webfont.svg
# cp webfont-Hack/hack-italic-webfont.svg ../../build/webfonts/fonts/svg/hack-italic-webfont.svg
# cp webfont-Hack/hack-bold-webfont.svg ../../build/webfonts/fonts/svg/hack-bold-webfont.svg
# cp webfont-Hack/hack-bolditalic-webfont.svg ../../build/webfonts/fonts/svg/hack-bolditalic-webfont.svg

# echo "SVG files copied to webfonts release directories"

# Web TTF Latin subset
cp webfont-Hack-Latin/hack-regular-latin-webfont.ttf ../../build/webfonts/fonts/web-ttf/latin/hack-regular-latin-webfont.ttf
cp webfont-Hack-Latin/hack-italic-latin-webfont.ttf ../../build/webfonts/fonts/web-ttf/latin/hack-italic-latin-webfont.ttf
cp webfont-Hack-Latin/hack-bold-latin-webfont.ttf ../../build/webfonts/fonts/web-ttf/latin/hack-bold-latin-webfont.ttf
cp webfont-Hack-Latin/hack-bolditalic-latin-webfont.ttf ../../build/webfonts/fonts/web-ttf/latin/hack-bolditalic-latin-webfont.ttf

# Web TTF entire set
cp webfont-Hack/hack-regular-webfont.ttf ../../build/webfonts/fonts/web-ttf/hack-regular-webfont.ttf
cp webfont-Hack/hack-italic-webfont.ttf ../../build/webfonts/fonts/web-ttf/hack-italic-webfont.ttf
cp webfont-Hack/hack-bold-webfont.ttf ../../build/webfonts/fonts/web-ttf/hack-bold-webfont.ttf
cp webfont-Hack/hack-bolditalic-webfont.ttf ../../build/webfonts/fonts/web-ttf/hack-bolditalic-webfont.ttf

echo "TTF files copied to webfonts release directories"

# WOFF Latin subset
cp webfont-Hack-Latin/hack-regular-latin-webfont.woff ../../build/webfonts/fonts/woff/latin/hack-regular-latin-webfont.woff
cp webfont-Hack-Latin/hack-italic-latin-webfont.woff ../../build/webfonts/fonts/woff/latin/hack-italic-latin-webfont.woff
cp webfont-Hack-Latin/hack-bold-latin-webfont.woff ../../build/webfonts/fonts/woff/latin/hack-bold-latin-webfont.woff
cp webfont-Hack-Latin/hack-bolditalic-latin-webfont.woff ../../build/webfonts/fonts/woff/latin/hack-bolditalic-latin-webfont.woff

# WOFF entire set
cp webfont-Hack/hack-regular-webfont.woff ../../build/webfonts/fonts/woff/hack-regular-webfont.woff
cp webfont-Hack/hack-italic-webfont.woff ../../build/webfonts/fonts/woff/hack-italic-webfont.woff
cp webfont-Hack/hack-bold-webfont.woff ../../build/webfonts/fonts/woff/hack-bold-webfont.woff
cp webfont-Hack/hack-bolditalic-webfont.woff ../../build/webfonts/fonts/woff/hack-bolditalic-webfont.woff

echo "WOFF files copied to webfonts release directories"

# WOFF2 Latin subset
cp webfont-Hack-Latin/hack-regular-latin-webfont.woff2 ../../build/webfonts/fonts/woff2/latin/hack-regular-latin-webfont.woff2
cp webfont-Hack-Latin/hack-italic-latin-webfont.woff2 ../../build/webfonts/fonts/woff2/latin/hack-italic-latin-webfont.woff2
cp webfont-Hack-Latin/hack-bold-latin-webfont.woff2 ../../build/webfonts/fonts/woff2/latin/hack-bold-latin-webfont.woff2
cp webfont-Hack-Latin/hack-bolditalic-latin-webfont.woff2 ../../build/webfonts/fonts/woff2/latin/hack-bolditalic-latin-webfont.woff2

# WOFF2 entire set
cp webfont-Hack/hack-regular-webfont.woff2 ../../build/webfonts/fonts/woff2/hack-regular-webfont.woff2
cp webfont-Hack/hack-italic-webfont.woff2 ../../build/webfonts/fonts/woff2/hack-italic-webfont.woff2
cp webfont-Hack/hack-bold-webfont.woff2 ../../build/webfonts/fonts/woff2/hack-bold-webfont.woff2
cp webfont-Hack/hack-bolditalic-webfont.woff2 ../../build/webfonts/fonts/woff2/hack-bolditalic-webfont.woff2

echo "WOFF2 files copied to webfonts release directories"




